{% load feincms_page_tags %}
{% load mptt_tags %}


<ul id="{{ nav_id|default:"top-level" }}">
    {% feincms_nav feincms_page level=1 depth=depth|default:1 as navitems %}
    {% with navitems|siblings_along_path_to:feincms_page as navtree %}
        {% recursetree navitems %}
            {% page_is_active node as is_active %}
            <li class="{% if is_active %}selected{% endif %} {% if children %}has-children{% endif %}">
                <span><a href="{{ node.get_absolute_url }}">{{ node.short_title }}</a></span>
            </li>
            {% if children %}
                <ul>
                    {{ children }}
                </ul>
            {% endif %}
        {% endrecursetree %}
    {% endwith %}
</ul>
